
# AM_RED-Channel
### Created by Amr_MAM
### Easy to make connection between Node-RED and Python

## Getting Started
### 1 - Open Node-RED
### 2 - from [Manage palette] install "am_red-nodes"
### 3 - drop the channel node down in the workspace
### 4 - drop the end of channel node down to the work
### 5 - configure the channel id, and method ex: "recieve" 
### 6 - match the each node to each other
### 7 - take a signal to debug from the channel node to see what happens
### 8 - deploy you project

### 9 - open python editor
### 10- import this library
### 11- write print(AM_SendDataSameDevice(id = id_choosen, data = '1')
### 12- run code and see what changes in the both sides